SimulatedClock

Struct SimulatedClock 

pub struct SimulatedClock { /* private fields */ }
Simulated wall clock with drift, skew, and freeze controls.

Implementations

Source

impl SimulatedClock

pub const fn new(spec: ClockSpec) -> Self

Create a simulated clock from an assigned spec.

pub const fn spec(&self) -> ClockSpec

Return the assigned spec.

pub fn now_millis(&self, round: u64) -> i64

Return current wall time in milliseconds for a simulation round.

pub fn freeze(&mut self, round: u64)

Freeze this clock at the current time.

pub const fn unfreeze(&mut self)

Unfreeze this clock.

pub const fn is_frozen(&self) -> bool

Whether this clock is currently frozen.