pub struct FaultConfig {
pub max_delay_rounds: u8,
pub drop_rate_percent: u8,
pub duplicate_rate_percent: u8,
pub reorder_rate_percent: u8,
pub partition_rate_percent: u8,
pub freeze_rate_percent: u8,
pub freeze_duration_rounds: u8,
}Expand description
Fault injection configuration for simulated network delivery.
Fields
max_delay_rounds: u8Maximum delivery delay in rounds.
drop_rate_percent: u8Percentage of sends dropped.
duplicate_rate_percent: u8Percentage of sends duplicated.
reorder_rate_percent: u8Percentage chance of reordering ready messages at each tick.
partition_rate_percent: u8Percentage chance per round to toggle a random network partition.
freeze_rate_percent: u8Percentage chance per round to freeze a random clock.
freeze_duration_rounds: u8Number of rounds to keep a frozen clock frozen.