pub struct SimulatedClock { /* private fields */ }Expand description
Simulated wall clock with drift, skew, and freeze controls.
Implementations
Sourceimpl SimulatedClock
impl SimulatedClock
Sourcepub fn now_millis(&self, round: u64) -> i64
pub fn now_millis(&self, round: u64) -> i64
Return current wall time in milliseconds for a simulation round.